==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/cws/v20180312/models/ModifyConfigAttributeRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ModifyConfigAttributeRequest  extends AbstractModel{

    /**
    * 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
    */
    @SerializedName("NoticeLevel")
    @Expose
    private String NoticeLevel;

    /**
     * 获取漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     * @return NoticeLevel 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     */
    public String getNoticeLevel() {
        return this.NoticeLevel;
    }

    /**
     * 设置漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     * @param NoticeLevel 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     */
    public void setNoticeLevel(String NoticeLevel) {
        this.NoticeLevel = NoticeLevel;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "NoticeLevel", this.NoticeLevel);

    }
}

==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/cws/v20180312/models/ModifyConfigAttributeRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ModifyConfigAttributeRequest extends AbstractModel{

    /**
    * 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
    */
    @SerializedName("NoticeLevel")
    @Expose
    private String NoticeLevel;

    /**
     * Get 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示 
     * @return NoticeLevel 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     */
    public String getNoticeLevel() {
        return this.NoticeLevel;
    }

    /**
     * Set 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     * @param NoticeLevel 漏洞告警通知等级，4位分别代表：高危、中危、低危、提示
     */
    public void setNoticeLevel(String NoticeLevel) {
        this.NoticeLevel = NoticeLevel;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "NoticeLevel", this.NoticeLevel);

    }
}
